@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-app-static
 version: 3.1.5
-id: wai-app-static-3.1.5-9c470d1531d667f785392fcc70a11537
-key: waiap_2AWvqPnfuH7GsfwLiTEpQb
+id: wai-app-static-3.1.5-4b08fd9013eda7d6300c1fd3284ff8ba
+key: waiap_5aFlrcp5azX5mm5coRvvwO
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -24,7 +24,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.5
-hs-libraries: HSwai-app-static-3.1.5-2AWvqPnfuH7GsfwLiTEpQb
+hs-libraries: HSwai-app-static-3.1.5-5aFlrcp5azX5mm5coRvvwO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
@@ -50,7 +50,7 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
     wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
-    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
+    warp-3.2.6-0273436dc44d76eb20f09024e8daa00c
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
 haddock-html: /usr/share/doc/haskell-wai-app-static/html
